# Table of Contents

- [application-portfolio-management-dashboard](<./application-portfolio-management-dashboard.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Application Portfolio Management Dashboard](<./Application-Portfolio-Management-Dashboard.md>)
  - [Dashboard Structure](<./Application-Portfolio-Management-Dashboard/Dashboard-Structure.md>)
  - [General Features of the Dashboard](<./Application-Portfolio-Management-Dashboard/General-Features-of-the-Dashboard.md>)
  - [Live Applications by Business Capability](<./Application-Portfolio-Management-Dashboard/Live-Applications-by-Business-Capability.md>)
  - [Application Run Cost Broken Down by Business Capability](<./Application-Portfolio-Management-Dashboard/Application-Run-Cost-Broken-Down-by-Business-Capability.md>)
  - [Portfolio Complexity](<./Application-Portfolio-Management-Dashboard/Portfolio-Complexity.md>)
  - [Data Quality KPI](<./Application-Portfolio-Management-Dashboard/Data-Quality-KPI.md>)
  - [Was this page helpful?](<./Application-Portfolio-Management-Dashboard/Was-this-page-helpful.md>)
  - [We'd love your feedback!](<./Application-Portfolio-Management-Dashboard/Wed-love-your-feedback.md>)
